@@ -7,6 +7,7 @@ class ContentType(IntEnum):
     employee = 22
     branch = 35
     employee_leave = 50
+    api_authorisation = 73
     settings = 86
     employee_overtime_rule_detail = 103
     employee_group_membership = 105
@@ -22,4 +23,5 @@ class ContentType(IntEnum):
     company_profile_user_membership_email_confirm = 115
     visitor_group_membership = 116
     visitor_group_area_membership = 117
-    current_company_profile = 118
\ No newline at end of file
+    current_company_profile = 118
+    daily_overtime_data = 202
\ No newline at end of file
